@@ -35,9 +35,9 @@ DEFAULT_SETTINGS = os.path.join(BASE_DIR, "settings.yaml")
 
 settings = LazySettings(
     environments=True,
-    GLOBAL_ENV_FOR_DYNACONF="ARA",
+    ENVVAR_PREFIX_FOR_DYNACONF="ARA",
     ENVVAR_FOR_DYNACONF="ARA_SETTINGS",
-    SETTINGS_MODULE_FOR_DYNACONF=DEFAULT_SETTINGS,
+    SETTINGS_FILE_FOR_DYNACONF=DEFAULT_SETTINGS,
 )
 
 # reread BASE_DIR since it might have gotten changed in the config file.
@@ -48,39 +48,40 @@ BASE_DIR = settings.get("BASE_DIR", BASE_DIR)
 DEBUG = settings.get("DEBUG", False, "@bool")
 
 LOG_LEVEL = settings.get("LOG_LEVEL", "INFO")
-# fmt: off
-LOGGING = {
-    "version": 1,
-    "disable_existing_loggers": False,
-    "formatters": {"normal": {"format": "%(asctime)s %(levelname)s %(name)s: %(message)s"}},
-    "handlers": {
-        "console": {
-            "class": "logging.StreamHandler",
-            "formatter": "normal",
-            "level": LOG_LEVEL,
-            "stream": "ext://sys.stdout",
-        }
+# default logger updated cf issue https://github.com/ansible-community/ara/issues/228
+# and PR https://github.com/ansible-community/ara/pull/367
+LOGGING = settings.get(
+    "LOGGING",
+    {
+        "version": 1,
+        "disable_existing_loggers": False,
+        "formatters": {"normal": {"format": "%(asctime)s %(levelname)s %(name)s: %(message)s"}},
+        "handlers": {
+            "console": {
+                "class": "logging.StreamHandler",
+                "formatter": "normal",
+                "level": LOG_LEVEL,
+                "stream": "ext://sys.stdout",
+            }
+        },
+        "loggers": {"ara": {"handlers": ["console"], "level": LOG_LEVEL, "propagate": 0}},
     },
-    "loggers": {
-        "ara": {
-            "handlers": ["console"],
-            "level": LOG_LEVEL,
-            "propagate": 0
-        }
-    },
-    "root": {
-        "handlers": ["console"],
-        "level": LOG_LEVEL
-    },
-}
-# fmt: on
+).to_dict()
 
+if "root" in LOGGING:
+    print(
+        "[ara] Server's LOGGING configuration has a 'root' logger which is deprecated after version 1.5.8 "
+        "due to conflicts. Please update your settings.yaml or generate a new one by "
+        "removing it from ara's configuration folder"
+    )
+    del LOGGING["root"]
 
 # Django built-in server and npm development server
 ALLOWED_HOSTS = settings.get("ALLOWED_HOSTS", ["::1", "127.0.0.1", "localhost"])
 CORS_ORIGIN_WHITELIST = settings.get("CORS_ORIGIN_WHITELIST", ["http://127.0.0.1:8000", "http://localhost:3000"])
 CORS_ORIGIN_REGEX_WHITELIST = settings.get("CORS_ORIGIN_REGEX_WHITELIST", [])
 CORS_ORIGIN_ALLOW_ALL = settings.get("CORS_ORIGIN_ALLOW_ALL", False)
+CSRF_TRUSTED_ORIGINS = settings.get("CSRF_TRUSTED_ORIGINS", [])
 
 ADMINS = settings.get("ADMINS", ())
 
@@ -242,7 +243,7 @@ REST_FRAMEWORK = {
     "DEFAULT_FILTER_BACKENDS": ("django_filters.rest_framework.DjangoFilterBackend",),
     "DEFAULT_RENDERER_CLASSES": (
         "rest_framework.renderers.JSONRenderer",
-        "rest_framework.renderers.BrowsableAPIRenderer",
+        "ara.api.renderers.BrowsableAPIRendererWithoutForms",
     ),
     "DEFAULT_PARSER_CLASSES": (
         "rest_framework.parsers.JSONParser",
@@ -271,6 +272,7 @@ if not os.path.exists(DEFAULT_SETTINGS) and "ARA_SETTINGS" not in os.environ:
         CORS_ORIGIN_WHITELIST=CORS_ORIGIN_WHITELIST.to_list(),
         CORS_ORIGIN_REGEX_WHITELIST=CORS_ORIGIN_REGEX_WHITELIST.to_list(),
         CORS_ORIGIN_ALLOW_ALL=CORS_ORIGIN_ALLOW_ALL,
+        CSRF_TRUSTED_ORIGINS=CSRF_TRUSTED_ORIGINS.to_list(),
         EXTERNAL_AUTH=EXTERNAL_AUTH,
         SECRET_KEY=SECRET_KEY,
         DATABASE_ENGINE=DATABASE_ENGINE,
